#ifndef XML_H
#define XML_H

#include <gnome-xml/parser.h>
#include <gnome-xml/tree.h>

xmlNodePtr xml_search_child( xmlNodePtr node, const char *name );
char* xml_get_value( xmlNodePtr node, const char *name );

#endif
